summaryrefslogtreecommitdiff
path: root/gcc/gcov-io.c
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2003-06-12 19:01:08 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2003-06-12 19:01:08 +0000
commit7ef5b942a1ad681e5124f1949bd5f62c0d7456a4 (patch)
tree0f2925fe84100a624006d902c347d9fea822e422 /gcc/gcov-io.c
parentdf9c4f4c2c4d2ab2a9fc20eceb43d87c971c627c (diff)
downloadgcc-7ef5b942a1ad681e5124f1949bd5f62c0d7456a4.tar.gz
* ChangeLog: Follow spelling conventions.
* ChangeLog.2: Likewise. * c-decl.c: Likewise. * cfgloop.h: Likewise. * cgraph.c: Likewise. * coverage.c: Likewise. * cppcharset.c: Likewise. * cpphash.h: Likewise. * cpplex.c: Likewise. * cpplib.c: Likewise. * dbxout.c: Likewise. * df.c: Likewise. * dwarf2out.c: Likewise. * dwarfout.c: Likewise. * emit-rtl.c: Likewise. * explow.c: Likewise. * gcov-io.c: Likewise. * gcov-io.h: Likewise. * gcov.c: Likewise. * gengtype.c: Likewise. * ggc.h: Likewise. * opts.c: Likewise. * real.c: Likewise. * reload.c: Likewise. * stmt.c: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@67849 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/gcov-io.c')
-rw-r--r--gcc/gcov-io.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/gcov-io.c b/gcc/gcov-io.c
index 94197c962e6..112e77caa77 100644
--- a/gcc/gcov-io.c
+++ b/gcc/gcov-io.c
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
return;
}
/* Write a summary structure to the gcov file. Return non-zero on
overflow. */
GCOV_LINKAGE void
@@ -489,7 +489,7 @@ gcov_sync (gcov_position_t base, gcov_unsigned_t length)
#if IN_LIBGCOV
/* Move to the a set position in a gcov file. BASE is zero to move to
- the end, and non-zero to move to that position. */
+ the end, and nonzero to move to that position. */
GCOV_LINKAGE void
gcov_seek (gcov_position_t base)
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
return;
}
-/* Write a summary structure to the gcov file. Return non-zero on
+/* Write a summary structure to the gcov file. Return nonzero on
overflow. */
GCOV_LINKAGE void